.. _examples:


.. title:: Examples

.. currentmodule:: pyuv


UDP Echo server
***************

.. literalinclude:: ../examples/echo-server-udp.py


TCP Echo server
***************

.. literalinclude:: ../examples/echo-server-tcp.py


TCP Echo server using Poll handles
**********************************

.. literalinclude:: ../examples/echo-server-poll.py


Standard IO Echo server using Pipe handles
******************************************

.. literalinclude:: ../examples/echo-pipe.py


Standard IO Echo server using TTY handles
*****************************************

.. literalinclude:: ../examples/echo-tty.py

